@@ -3,7 +3,6 @@
 use glib::translate::*;
 use gst::prelude::*;
 use std::cmp;
-use std::convert::{TryFrom, TryInto};
 use std::fmt;
 use std::mem;
 use std::ptr;
@@ -47,8 +46,8 @@ impl VideoTimeCode {
             let mut v = mem::MaybeUninit::zeroed();
             ffi::gst_video_time_code_init(
                 v.as_mut_ptr(),
-                *fps.numer() as u32,
-                *fps.denom() as u32,
+                fps.numer() as u32,
+                fps.denom() as u32,
                 latest_daily_jam.to_glib_none().0,
                 flags.into_glib(),
                 hours,
@@ -72,13 +71,13 @@ impl VideoTimeCode {
         field_count: u32,
     ) -> Result<Self, glib::error::BoolError> {
         assert_initialized_main_thread!();
-        assert!(*fps.denom() > 0);
+        assert!(fps.denom() > 0);
         unsafe {
             let mut v = mem::MaybeUninit::zeroed();
             let res = ffi::gst_video_time_code_init_from_date_time_full(
                 v.as_mut_ptr(),
-                *fps.numer() as u32,
-                *fps.denom() as u32,
+                fps.numer() as u32,
+                fps.denom() as u32,
                 dt.to_glib_none().0,
                 flags.into_glib(),
                 field_count,
@@ -98,8 +97,8 @@ impl VideoTimeCode {
     }
 
     pub fn set_fps(&mut self, fps: gst::Fraction) {
-        self.0.config.fps_n = *fps.numer() as u32;
-        self.0.config.fps_d = *fps.denom() as u32;
+        self.0.config.fps_n = fps.numer() as u32;
+        self.0.config.fps_d = fps.denom() as u32;
     }
 
     pub fn set_flags(&mut self, flags: VideoTimeCodeFlags) {
@@ -445,6 +444,8 @@ macro_rules! generic_impl {
             type Type = Self;
         }
 
+        impl glib::value::ValueTypeOptional for $name {}
+
         #[doc(hidden)]
         unsafe impl<'a> glib::value::FromValue<'a> for $name {
             type Checker = glib::value::GenericValueTypeOrNoneChecker<Self>;
@@ -607,8 +608,6 @@ impl fmt::Debug for VideoTimeCodeMeta {
 #[cfg(feature = "v1_16")]
 #[cfg(test)]
 mod tests {
-    use super::*;
-
     #[test]
     fn test_add_get_set_meta() {
         gst::init().unwrap();
@@ -616,7 +615,7 @@ mod tests {
         let mut buffer = gst::Buffer::new();
         {
             let datetime =
-                glib::DateTime::new_utc(2021, 2, 4, 10, 53, 17.0).expect("can't create datetime");
+                glib::DateTime::from_utc(2021, 2, 4, 10, 53, 17.0).expect("can't create datetime");
             let time_code = crate::VideoTimeCode::from_date_time(
                 gst::Fraction::new(30, 1),
                 &datetime,
@@ -632,7 +631,7 @@ mod tests {
             );
 
             let datetime =
-                glib::DateTime::new_utc(2021, 2, 4, 10, 53, 17.0).expect("can't create datetime");
+                glib::DateTime::from_utc(2021, 2, 4, 10, 53, 17.0).expect("can't create datetime");
             let mut time_code_2 = crate::ValidVideoTimeCode::try_from(
                 crate::VideoTimeCode::from_date_time(
                     gst::Fraction::new(30, 1),
